@@ -23,6 +23,7 @@
 #include "common.h"
 #include "fft.h"
 #include "support.h"
+#include <sys/ioctl.h>
 
 /* Transceiver type */
 enum
@@ -34,5 +35,7 @@ enum
   K3
 };
 
+#define MAX_SERIAL_RETRIES	10
+
 #endif
 
